@@ -30,19 +30,19 @@
 #'
 #' @keywords internal
 suggest_layout_from_previous <- function(previous_stage, telemetry_flags = NULL) {
-  # Extract and normalize text from various fields in previous_stage
-  # Handle both flattened columns (from bid_interpret) and nested data_story
+  # extract and normalize text from various fields in previous_stage
+  # handle both flattened columns (from bid_interpret) and nested data_story
   txt <- paste(
     safe_lower(safe_column_access(previous_stage, "problem", "")),
     safe_lower(safe_column_access(previous_stage, "evidence", "")),
     safe_lower(safe_column_access(previous_stage, "central_question", "")),
-    # Try flattened columns first (from bid_interpret output)
+    # try flattened columns first (from bid_interpret output)
     safe_lower(safe_column_access(previous_stage, "hook", "")),
     safe_lower(safe_column_access(previous_stage, "context", "")),
     safe_lower(safe_column_access(previous_stage, "tension", "")),
     safe_lower(safe_column_access(previous_stage, "resolution", "")),
     safe_lower(safe_column_access(previous_stage, "audience", "")),
-    # Fallback to nested data_story access (for other tibble structures)
+    # fallback to nested data_story access (for other tibble structures)
     safe_lower(safe_stage_data_story_access(previous_stage, "hook")),
     safe_lower(safe_stage_data_story_access(previous_stage, "context")),
     safe_lower(safe_stage_data_story_access(previous_stage, "tension")),
@@ -51,7 +51,7 @@ suggest_layout_from_previous <- function(previous_stage, telemetry_flags = NULL)
     collapse = " "
   )
 
-  # Heuristic 1: Dual-process for overview vs detail patterns
+  # heuristic 1: dual-process for overview vs detail patterns
   # (check first since it's more specific)
   if (
     grepl(
@@ -67,8 +67,11 @@ suggest_layout_from_previous <- function(previous_stage, telemetry_flags = NULL)
     grepl(
       "\\boverload|overwhelmed|too many|confus|clutter|busy|noise|cognitive load|whitespace\\b",
       txt
-    ) ||
-    (!is.null(telemetry_flags) && isTRUE(telemetry_flags$has_confusion_patterns))
+    ) || (
+      !is.null(telemetry_flags) && isTRUE(
+        telemetry_flags$has_confusion_patterns
+      )
+    )
   ) {
     return("breathable")
   }
@@ -124,18 +127,18 @@ suggest_layout_from_previous <- function(previous_stage, telemetry_flags = NULL)
 #' @keywords internal
 layout_rationale <- function(previous_stage, chosen) {
   # Extract text for pattern matching
-  # Handle both flattened columns (from bid_interpret) and nested data_story
+  # handle both flattened columns (from bid_interpret) and nested data_story
   txt <- paste(
     safe_lower(safe_column_access(previous_stage, "problem", "")),
     safe_lower(safe_column_access(previous_stage, "evidence", "")),
     safe_lower(safe_column_access(previous_stage, "central_question", "")),
-    # Try flattened columns first (from bid_interpret output)
+    # try flattened columns first (from bid_interpret output)
     safe_lower(safe_column_access(previous_stage, "hook", "")),
     safe_lower(safe_column_access(previous_stage, "context", "")),
     safe_lower(safe_column_access(previous_stage, "tension", "")),
     safe_lower(safe_column_access(previous_stage, "resolution", "")),
     safe_lower(safe_column_access(previous_stage, "audience", "")),
-    # Fallback to nested data_story access (for other tibble structures)
+    # fallback to nested data_story access (for other tibble structures)
     safe_lower(safe_stage_data_story_access(previous_stage, "hook")),
     safe_lower(safe_stage_data_story_access(previous_stage, "context")),
     safe_lower(safe_stage_data_story_access(previous_stage, "tension")),
@@ -145,8 +148,7 @@ layout_rationale <- function(previous_stage, chosen) {
   )
 
   # Generate specific rationale based on detected patterns
-  rationale <- switch(
-    chosen,
+  rationale <- switch(chosen,
     "dual_process" = {
       "Detected overview vs detail patterns; choosing 'dual_process' for quick insights and detailed analysis."
     },
@@ -450,10 +452,9 @@ infer_concepts_from_story <- function(previous_stage) {
 #' @return List of concept groups with suggestions
 #' @keywords internal
 build_groups_with_suggestions <- function(
-  concepts_final,
-  chosen_layout,
-  previous_stage
-) {
+    concepts_final,
+    chosen_layout,
+    previous_stage) {
   # ensure at least some core concepts if none provided
   if (length(concepts_final) == 0) {
     concepts_final <- c("Cognitive Load Theory", "Visual Hierarchy")
@@ -487,8 +488,7 @@ build_groups_with_suggestions <- function(
 #' @return List with concept name and suggestions
 #' @keywords internal
 build_concept_group <- function(concept, chosen_layout, previous_stage) {
-  suggestions <- switch(
-    concept,
+  suggestions <- switch(concept,
     "Cognitive Load Theory" = get_cognitive_load_suggestions(
       chosen_layout,
       previous_stage
@@ -582,9 +582,8 @@ get_cognitive_load_suggestions <- function(chosen_layout, previous_stage) {
 #' Generate Progressive Disclosure suggestions
 #' @keywords internal
 get_progressive_disclosure_suggestions <- function(
-  chosen_layout,
-  previous_stage
-) {
+    chosen_layout,
+    previous_stage) {
   base_suggestions <- list(
     list(
       title = "Use collapsible advanced filters",
@@ -798,11 +797,10 @@ rank_and_sort_suggestions <- function(groups, previous_stage, chosen_layout) {
 #' Apply context-based scoring adjustments
 #' @keywords internal
 adjust_suggestion_score <- function(
-  suggestion,
-  previous_stage,
-  chosen_layout,
-  concept
-) {
+    suggestion,
+    previous_stage,
+    chosen_layout,
+    concept) {
   score <- suggestion$score
 
   # boost if concept originated from Stage 1 theory
