@@ -6,10 +6,7 @@ test_that("bid_stage constructor creates valid objects", {
   )
 
   result <- bid_stage("Notice", test_data)
-
-  expect_s3_class(result, "bid_stage")
-  expect_s3_class(result, "tbl_df")
-  expect_equal(get_stage(result), "Notice")
+  validate_bid_stage_structure(result, "Notice")
 })
 
 test_that("bid_stage validation works correctly", {
@@ -19,16 +16,16 @@ test_that("bid_stage validation works correctly", {
     timestamp = Sys.time()
   )
 
-  # Valid stage should work
+  # valid stage should work
   expect_silent(bid_stage("Notice", test_data))
 
-  # Invalid stage should error
+  # invalid stage should error
   expect_error(
     bid_stage("InvalidStage", test_data),
     "Stage must be one of:"
   )
 
-  # Mismatched stage attribute and column should error
+  # mismatched stage attribute and column should error
   wrong_data <- tibble(
     stage = "Interpret",
     problem = "Test problem",
@@ -39,7 +36,7 @@ test_that("bid_stage validation works correctly", {
     "Stage attribute must match stage column value"
   )
 
-  # Missing timestamp should error
+  # missing timestamp should error
   no_timestamp <- tibble(
     stage = "Notice",
     problem = "Test problem"
@@ -51,16 +48,12 @@ test_that("bid_stage validation works correctly", {
 })
 
 test_that("is_bid_stage works correctly", {
-  test_data <- tibble(
-    stage = "Notice",
-    problem = "Test problem",
-    timestamp = Sys.time()
-  )
-
-  stage_obj <- bid_stage("Notice", test_data)
+  stage_obj <- bid_stage("Notice", tibble(
+    stage = "Notice", problem = "Test", timestamp = Sys.time()
+  ))
 
   expect_true(is_bid_stage(stage_obj))
-  expect_false(is_bid_stage(test_data))
+  expect_false(is_bid_stage(tibble(a = 1)))
   expect_false(is_bid_stage(NULL))
   expect_false(is_bid_stage("string"))
 })
@@ -78,83 +71,32 @@ test_that("get_stage and get_metadata work correctly", {
   expect_equal(get_stage(stage_obj), "Notice")
   expect_equal(get_metadata(stage_obj), metadata)
 
-  # Should error for non-bid_stage objects
+  # should error for non-bid_stage objects
   expect_error(get_stage(test_data), "Object is not a bid_stage")
   expect_error(get_metadata(test_data), "Object is not a bid_stage")
 })
 
-test_that("print.bid_stage works for all stage types", {
-  # Notice stage
-  notice_data <- tibble(
-    stage = "Notice",
-    problem = "Test problem",
-    theory = "Test theory",
-    evidence = "Test evidence",
-    target_audience = "Test audience",
-    suggestions = "Test suggestions",
-    timestamp = Sys.time()
+test_that("print.bid_stage displays core information", {
+  # test key stages with essential output
+  stages_data <- list(
+    Notice = list(problem = "Test problem", theory = "Test theory"),
+    Interpret = list(central_question = "Test question", hook = "Test hook"),
+    Structure = list(layout = "breathable", concepts = "Visual Hierarchy"),
+    Anticipate = list(bias_mitigations = "anchoring: test"),
+    Validate = list(summary_panel = "Clear summary")
   )
-  notice_obj <- bid_stage("Notice", notice_data)
 
-  expect_output(print(notice_obj), "BID Framework")
-  expect_output(print(notice_obj), "Notice Stage")
-  expect_output(print(notice_obj), "Problem:")
-  expect_output(print(notice_obj), "Theory:")
+  for (stage_name in names(stages_data)) {
+    stage_data <- stages_data[[stage_name]]
+    stage_data$stage <- stage_name
+    stage_data$suggestions <- "Test suggestions"
+    stage_data$timestamp <- Sys.time()
 
-  # Interpret stage
-  interpret_data <- tibble(
-    stage = "Interpret",
-    central_question = "Test question",
-    hook = "Test hook",
-    suggestions = "Test suggestions",
-    timestamp = Sys.time()
-  )
-  interpret_obj <- bid_stage("Interpret", interpret_data)
+    stage_obj <- bid_stage(stage_name, tibble::tibble(!!!stage_data))
 
-  expect_output(print(interpret_obj), "Interpret Stage")
-  expect_output(print(interpret_obj), "Central Question:")
-
-  # Structure stage
-  structure_data <- tibble(
-    stage = "Structure",
-    layout = "breathable",
-    concepts = "Visual Hierarchy, Cognitive Load",
-    accessibility = "WCAG AA compliant",
-    suggestions = "Test suggestions",
-    timestamp = Sys.time()
-  )
-  structure_obj <- bid_stage("Structure", structure_data)
-
-  expect_output(print(structure_obj), "Structure Stage")
-  expect_output(print(structure_obj), "Layout:")
-  expect_output(print(structure_obj), "Concepts:")
-
-  # Anticipate stage
-  anticipate_data <- tibble(
-    stage = "Anticipate",
-    bias_mitigations = "anchoring: test; framing: test",
-    interaction_principles = "hover feedback",
-    suggestions = "Test suggestions",
-    timestamp = Sys.time()
-  )
-  anticipate_obj <- bid_stage("Anticipate", anticipate_data)
-
-  expect_output(print(anticipate_obj), "Anticipate Stage")
-  expect_output(print(anticipate_obj), "Bias Mitigations:")
-
-  # Validate stage
-  validate_data <- tibble(
-    stage = "Validate",
-    summary_panel = "Clear summary of insights",
-    next_steps = "Test step 1; Test step 2",
-    collaboration = "Team sharing features",
-    suggestions = "Test suggestions",
-    timestamp = Sys.time()
-  )
-  validate_obj <- bid_stage("Validate", validate_data)
-
-  expect_output(print(validate_obj), "Validate Stage")
-  expect_output(print(validate_obj), "Summary Panel:")
+    expect_output(print(stage_obj), "BID Framework")
+    expect_output(print(stage_obj), paste(stage_name, "Stage"))
+  }
 })
 
 test_that("summary.bid_stage works correctly", {
@@ -199,29 +141,29 @@ test_that("as_tibble.bid_stage works correctly", {
 })
 
 test_that("bid_result constructor and validation work", {
-  # Create test stages
+  # create test stages
   stage1_data <- tibble(
-    stage = "Notice",
-    problem = "Test problem",
-    timestamp = Sys.time()
-  )
-  stage1 <- bid_stage("Notice", stage1_data)
-
-  stage2_data <- tibble(
     stage = "Interpret",
     central_question = "Test question",
     timestamp = Sys.time()
   )
-  stage2 <- bid_stage("Interpret", stage2_data)
+  stage1 <- bid_stage("Interpret", stage1_data)
 
-  # Create bid_result
+  stage2_data <- tibble(
+    stage = "Notice",
+    problem = "Test problem",
+    timestamp = Sys.time()
+  )
+  stage2 <- bid_stage("Notice", stage2_data)
+
+  # create bid_result
   result <- bid_result(list(stage1, stage2))
 
   expect_s3_class(result, "bid_result")
   expect_s3_class(result, "list")
   expect_length(result, 2)
 
-  # Should error with non-bid_stage objects
+  # should error with non-bid_stage objects
   expect_error(
     bid_result(list(stage1_data, stage2_data)),
     "All elements in BID result must be bid_stage objects"
@@ -230,18 +172,18 @@ test_that("bid_result constructor and validation work", {
 
 test_that("extract_stage works correctly", {
   stage1_data <- tibble(
-    stage = "Notice",
-    problem = "Test problem",
-    timestamp = Sys.time()
-  )
-  stage1 <- bid_stage("Notice", stage1_data)
-
-  stage2_data <- tibble(
     stage = "Interpret",
     central_question = "Test question",
     timestamp = Sys.time()
   )
-  stage2 <- bid_stage("Interpret", stage2_data)
+  stage1 <- bid_stage("Interpret", stage1_data)
+
+  stage2_data <- tibble(
+    stage = "Notice",
+    problem = "Test problem",
+    timestamp = Sys.time()
+  )
+  stage2 <- bid_stage("Notice", stage2_data)
 
   workflow <- bid_result(list(stage1, stage2))
 
@@ -252,7 +194,7 @@ test_that("extract_stage works correctly", {
   extracted_missing <- extract_stage(workflow, "Structure")
   expect_null(extracted_missing)
 
-  # Should error with non-bid_result
+  # should error with non-bid_result
   expect_error(
     extract_stage(list(stage1, stage2), "Notice"),
     "workflow must be a bid_result object"
@@ -260,20 +202,20 @@ test_that("extract_stage works correctly", {
 })
 
 test_that("is_complete works correctly", {
-  # Create incomplete workflow
+  # create incomplete workflow
   stage1_data <- tibble(
-    stage = "Notice",
-    problem = "Test problem",
+    stage = "Interpret",
+    central_question = "Test question",
     timestamp = Sys.time()
   )
-  stage1 <- bid_stage("Notice", stage1_data)
+  stage1 <- bid_stage("Interpret", stage1_data)
 
   incomplete_workflow <- bid_result(list(stage1))
   expect_false(is_complete(incomplete_workflow))
 
-  # Create complete workflow
+  # create complete workflow
   all_stages <- list()
-  stage_names <- c("Notice", "Interpret", "Structure", "Anticipate", "Validate")
+  stage_names <- c("Interpret", "Notice", "Anticipate", "Structure", "Validate")
 
   for (stage_name in stage_names) {
     stage_data <- tibble(
@@ -287,24 +229,24 @@ test_that("is_complete works correctly", {
   complete_workflow <- bid_result(all_stages)
   expect_true(is_complete(complete_workflow))
 
-  # Should return FALSE for non-bid_result
+  # should return FALSE for non-bid_result
   expect_false(is_complete(list(stage1)))
 })
 
 test_that("print.bid_result works correctly", {
   stage1_data <- tibble(
-    stage = "Notice",
-    problem = "Test problem",
-    timestamp = Sys.time()
-  )
-  stage1 <- bid_stage("Notice", stage1_data)
-
-  stage2_data <- tibble(
     stage = "Interpret",
     central_question = "Test question",
     timestamp = Sys.time()
   )
-  stage2 <- bid_stage("Interpret", stage2_data)
+  stage1 <- bid_stage("Interpret", stage1_data)
+
+  stage2_data <- tibble(
+    stage = "Notice",
+    problem = "Test problem",
+    timestamp = Sys.time()
+  )
+  stage2 <- bid_stage("Notice", stage2_data)
 
   workflow <- bid_result(list(stage1, stage2))
 
@@ -317,17 +259,16 @@ test_that("print.bid_result works correctly", {
 
 test_that("summary.bid_result works correctly", {
   stage1_data <- tibble(
-    stage = "Notice",
-    problem = "Test problem",
-    theory = "Test theory",
+    stage = "Interpret",
+    central_question = "Test question",
     timestamp = Sys.time()
   )
-  stage1 <- bid_stage("Notice", stage1_data)
+  stage1 <- bid_stage("Interpret", stage1_data)
 
   workflow <- bid_result(list(stage1))
 
   expect_output(summary(workflow), "BID Framework Workflow Summary")
   expect_output(summary(workflow), "Total stages: 1")
   expect_output(summary(workflow), "Complete workflow: No")
-  expect_output(summary(workflow), "1. Notice")
+  expect_output(summary(workflow), "1. Interpret")
 })
